# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.oslogin_v1.proto import (
    common_pb2 as google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2,
)
from google.cloud.oslogin_v1.proto import (
    oslogin_pb2 as google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class OsLoginServiceStub(object):
    """Cloud OS Login API

  The Cloud OS Login API allows you to manage users and their associated SSH
  public keys for logging into virtual machines on Google Cloud Platform.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.DeletePosixAccount = channel.unary_unary(
            "/google.cloud.oslogin.v1.OsLoginService/DeletePosixAccount",
            request_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.DeletePosixAccountRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.DeleteSshPublicKey = channel.unary_unary(
            "/google.cloud.oslogin.v1.OsLoginService/DeleteSshPublicKey",
            request_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.DeleteSshPublicKeyRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.GetLoginProfile = channel.unary_unary(
            "/google.cloud.oslogin.v1.OsLoginService/GetLoginProfile",
            request_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.GetLoginProfileRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.LoginProfile.FromString,
        )
        self.GetSshPublicKey = channel.unary_unary(
            "/google.cloud.oslogin.v1.OsLoginService/GetSshPublicKey",
            request_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.GetSshPublicKeyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2.SshPublicKey.FromString,
        )
        self.ImportSshPublicKey = channel.unary_unary(
            "/google.cloud.oslogin.v1.OsLoginService/ImportSshPublicKey",
            request_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.ImportSshPublicKeyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.ImportSshPublicKeyResponse.FromString,
        )
        self.UpdateSshPublicKey = channel.unary_unary(
            "/google.cloud.oslogin.v1.OsLoginService/UpdateSshPublicKey",
            request_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.UpdateSshPublicKeyRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2.SshPublicKey.FromString,
        )


class OsLoginServiceServicer(object):
    """Cloud OS Login API

  The Cloud OS Login API allows you to manage users and their associated SSH
  public keys for logging into virtual machines on Google Cloud Platform.
  """

    def DeletePosixAccount(self, request, context):
        """Deletes a POSIX account.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteSshPublicKey(self, request, context):
        """Deletes an SSH public key.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLoginProfile(self, request, context):
        """Retrieves the profile information used for logging in to a virtual machine
    on Google Compute Engine.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSshPublicKey(self, request, context):
        """Retrieves an SSH public key.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportSshPublicKey(self, request, context):
        """Adds an SSH public key and returns the profile information. Default POSIX
    account information is set when no username and UID exist as part of the
    login profile.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateSshPublicKey(self, request, context):
        """Updates an SSH public key and returns the profile information. This method
    supports patch semantics.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_OsLoginServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeletePosixAccount": grpc.unary_unary_rpc_method_handler(
            servicer.DeletePosixAccount,
            request_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.DeletePosixAccountRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "DeleteSshPublicKey": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteSshPublicKey,
            request_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.DeleteSshPublicKeyRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "GetLoginProfile": grpc.unary_unary_rpc_method_handler(
            servicer.GetLoginProfile,
            request_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.GetLoginProfileRequest.FromString,
            response_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.LoginProfile.SerializeToString,
        ),
        "GetSshPublicKey": grpc.unary_unary_rpc_method_handler(
            servicer.GetSshPublicKey,
            request_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.GetSshPublicKeyRequest.FromString,
            response_serializer=google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2.SshPublicKey.SerializeToString,
        ),
        "ImportSshPublicKey": grpc.unary_unary_rpc_method_handler(
            servicer.ImportSshPublicKey,
            request_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.ImportSshPublicKeyRequest.FromString,
            response_serializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.ImportSshPublicKeyResponse.SerializeToString,
        ),
        "UpdateSshPublicKey": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateSshPublicKey,
            request_deserializer=google_dot_cloud_dot_oslogin__v1_dot_proto_dot_oslogin__pb2.UpdateSshPublicKeyRequest.FromString,
            response_serializer=google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2.SshPublicKey.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.oslogin.v1.OsLoginService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/oslogin_v1/proto/oslogin.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.oslogin_v1.proto import (
    common_pb2 as google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/oslogin_v1/proto/oslogin.proto",
    package="google.cloud.oslogin.v1",
    syntax="proto3",
    serialized_pb=_b(
        '\n+google/cloud/oslogin_v1/proto/oslogin.proto\x12\x17google.cloud.oslogin.v1\x1a\x1cgoogle/api/annotations.proto\x1a(google/cloud/oslogin/common/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xa6\x02\n\x0cLoginProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x0eposix_accounts\x18\x02 \x03(\x0b\x32).google.cloud.oslogin.common.PosixAccount\x12Q\n\x0fssh_public_keys\x18\x03 \x03(\x0b\x32\x38.google.cloud.oslogin.v1.LoginProfile.SshPublicKeysEntry\x12\x11\n\tsuspended\x18\x04 \x01(\x08\x1a_\n\x12SshPublicKeysEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).google.cloud.oslogin.common.SshPublicKey:\x02\x38\x01")\n\x19\x44\x65letePosixAccountRequest\x12\x0c\n\x04name\x18\x01 \x01(\t")\n\x19\x44\x65leteSshPublicKeyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"&\n\x16GetLoginProfileRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"&\n\x16GetSshPublicKeyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x82\x01\n\x19ImportSshPublicKeyRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x41\n\x0essh_public_key\x18\x02 \x01(\x0b\x32).google.cloud.oslogin.common.SshPublicKey\x12\x12\n\nproject_id\x18\x03 \x01(\t"Z\n\x1aImportSshPublicKeyResponse\x12<\n\rlogin_profile\x18\x01 \x01(\x0b\x32%.google.cloud.oslogin.v1.LoginProfile"\x9d\x01\n\x19UpdateSshPublicKeyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x0essh_public_key\x18\x02 \x01(\x0b\x32).google.cloud.oslogin.common.SshPublicKey\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask2\xcd\x07\n\x0eOsLoginService\x12\x87\x01\n\x12\x44\x65letePosixAccount\x12\x32.google.cloud.oslogin.v1.DeletePosixAccountRequest\x1a\x16.google.protobuf.Empty"%\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/{name=users/*/projects/*}\x12\x8c\x01\n\x12\x44\x65leteSshPublicKey\x12\x32.google.cloud.oslogin.v1.DeleteSshPublicKeyRequest\x1a\x16.google.protobuf.Empty"*\x82\xd3\xe4\x93\x02$*"/v1/{name=users/*/sshPublicKeys/*}\x12\x92\x01\n\x0fGetLoginProfile\x12/.google.cloud.oslogin.v1.GetLoginProfileRequest\x1a%.google.cloud.oslogin.v1.LoginProfile"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{name=users/*}/loginProfile\x12\x99\x01\n\x0fGetSshPublicKey\x12/.google.cloud.oslogin.v1.GetSshPublicKeyRequest\x1a).google.cloud.oslogin.common.SshPublicKey"*\x82\xd3\xe4\x93\x02$\x12"/v1/{name=users/*/sshPublicKeys/*}\x12\xbe\x01\n\x12ImportSshPublicKey\x12\x32.google.cloud.oslogin.v1.ImportSshPublicKeyRequest\x1a\x33.google.cloud.oslogin.v1.ImportSshPublicKeyResponse"?\x82\xd3\xe4\x93\x02\x39"\'/v1/{parent=users/*}:importSshPublicKey:\x0essh_public_key\x12\xaf\x01\n\x12UpdateSshPublicKey\x12\x32.google.cloud.oslogin.v1.UpdateSshPublicKeyRequest\x1a).google.cloud.oslogin.common.SshPublicKey":\x82\xd3\xe4\x93\x02\x34\x32"/v1/{name=users/*/sshPublicKeys/*}:\x0essh_public_keyB\xa1\x01\n\x1b\x63om.google.cloud.oslogin.v1B\x0cOsLoginProtoP\x01Z>google.golang.org/genproto/googleapis/cloud/oslogin/v1;oslogin\xaa\x02\x17Google.Cloud.OsLogin.V1\xca\x02\x17Google\\Cloud\\OsLogin\\V1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_LOGINPROFILE_SSHPUBLICKEYSENTRY = _descriptor.Descriptor(
    name="SshPublicKeysEntry",
    full_name="google.cloud.oslogin.v1.LoginProfile.SshPublicKeysEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.oslogin.v1.LoginProfile.SshPublicKeysEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.oslogin.v1.LoginProfile.SshPublicKeysEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b("8\001")),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=407,
    serialized_end=502,
)

_LOGINPROFILE = _descriptor.Descriptor(
    name="LoginProfile",
    full_name="google.cloud.oslogin.v1.LoginProfile",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.oslogin.v1.LoginProfile.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="posix_accounts",
            full_name="google.cloud.oslogin.v1.LoginProfile.posix_accounts",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ssh_public_keys",
            full_name="google.cloud.oslogin.v1.LoginProfile.ssh_public_keys",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="suspended",
            full_name="google.cloud.oslogin.v1.LoginProfile.suspended",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_LOGINPROFILE_SSHPUBLICKEYSENTRY],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=208,
    serialized_end=502,
)


_DELETEPOSIXACCOUNTREQUEST = _descriptor.Descriptor(
    name="DeletePosixAccountRequest",
    full_name="google.cloud.oslogin.v1.DeletePosixAccountRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.oslogin.v1.DeletePosixAccountRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=504,
    serialized_end=545,
)


_DELETESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name="DeleteSshPublicKeyRequest",
    full_name="google.cloud.oslogin.v1.DeleteSshPublicKeyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.oslogin.v1.DeleteSshPublicKeyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=547,
    serialized_end=588,
)


_GETLOGINPROFILEREQUEST = _descriptor.Descriptor(
    name="GetLoginProfileRequest",
    full_name="google.cloud.oslogin.v1.GetLoginProfileRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.oslogin.v1.GetLoginProfileRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=590,
    serialized_end=628,
)


_GETSSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name="GetSshPublicKeyRequest",
    full_name="google.cloud.oslogin.v1.GetSshPublicKeyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.oslogin.v1.GetSshPublicKeyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=630,
    serialized_end=668,
)


_IMPORTSSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name="ImportSshPublicKeyRequest",
    full_name="google.cloud.oslogin.v1.ImportSshPublicKeyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.oslogin.v1.ImportSshPublicKeyRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ssh_public_key",
            full_name="google.cloud.oslogin.v1.ImportSshPublicKeyRequest.ssh_public_key",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="project_id",
            full_name="google.cloud.oslogin.v1.ImportSshPublicKeyRequest.project_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=671,
    serialized_end=801,
)


_IMPORTSSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
    name="ImportSshPublicKeyResponse",
    full_name="google.cloud.oslogin.v1.ImportSshPublicKeyResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="login_profile",
            full_name="google.cloud.oslogin.v1.ImportSshPublicKeyResponse.login_profile",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=803,
    serialized_end=893,
)


_UPDATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
    name="UpdateSshPublicKeyRequest",
    full_name="google.cloud.oslogin.v1.UpdateSshPublicKeyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.oslogin.v1.UpdateSshPublicKeyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ssh_public_key",
            full_name="google.cloud.oslogin.v1.UpdateSshPublicKeyRequest.ssh_public_key",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.oslogin.v1.UpdateSshPublicKeyRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=896,
    serialized_end=1053,
)

_LOGINPROFILE_SSHPUBLICKEYSENTRY.fields_by_name[
    "value"
].message_type = google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2._SSHPUBLICKEY
_LOGINPROFILE_SSHPUBLICKEYSENTRY.containing_type = _LOGINPROFILE
_LOGINPROFILE.fields_by_name[
    "posix_accounts"
].message_type = google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2._POSIXACCOUNT
_LOGINPROFILE.fields_by_name[
    "ssh_public_keys"
].message_type = _LOGINPROFILE_SSHPUBLICKEYSENTRY
_IMPORTSSHPUBLICKEYREQUEST.fields_by_name[
    "ssh_public_key"
].message_type = google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2._SSHPUBLICKEY
_IMPORTSSHPUBLICKEYRESPONSE.fields_by_name["login_profile"].message_type = _LOGINPROFILE
_UPDATESSHPUBLICKEYREQUEST.fields_by_name[
    "ssh_public_key"
].message_type = google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name["LoginProfile"] = _LOGINPROFILE
DESCRIPTOR.message_types_by_name[
    "DeletePosixAccountRequest"
] = _DELETEPOSIXACCOUNTREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteSshPublicKeyRequest"
] = _DELETESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name["GetLoginProfileRequest"] = _GETLOGINPROFILEREQUEST
DESCRIPTOR.message_types_by_name["GetSshPublicKeyRequest"] = _GETSSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name[
    "ImportSshPublicKeyRequest"
] = _IMPORTSSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name[
    "ImportSshPublicKeyResponse"
] = _IMPORTSSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name[
    "UpdateSshPublicKeyRequest"
] = _UPDATESSHPUBLICKEYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoginProfile = _reflection.GeneratedProtocolMessageType(
    "LoginProfile",
    (_message.Message,),
    dict(
        SshPublicKeysEntry=_reflection.GeneratedProtocolMessageType(
            "SshPublicKeysEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_LOGINPROFILE_SSHPUBLICKEYSENTRY,
                __module__="google.cloud.oslogin_v1.proto.oslogin_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.LoginProfile.SshPublicKeysEntry)
            ),
        ),
        DESCRIPTOR=_LOGINPROFILE,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""The user profile information used for logging in to a virtual machine on
  Google Compute Engine.
  
  
  Attributes:
      name:
          The primary email address that uniquely identifies the user.
      posix_accounts:
          The list of POSIX accounts associated with the user.
      ssh_public_keys:
          A map from SSH public key fingerprint to the associated key
          object.
      suspended:
          Indicates if the user is suspended. A suspended user cannot
          log in but their profile information is retained.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.LoginProfile)
    ),
)
_sym_db.RegisterMessage(LoginProfile)
_sym_db.RegisterMessage(LoginProfile.SshPublicKeysEntry)

DeletePosixAccountRequest = _reflection.GeneratedProtocolMessageType(
    "DeletePosixAccountRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEPOSIXACCOUNTREQUEST,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A request message for deleting a POSIX account entry.
  
  
  Attributes:
      name:
          A reference to the POSIX account to update. POSIX accounts are
          identified by the project ID they are associated with. A
          reference to the POSIX account is in format
          ``users/{user}/projects/{project}``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.DeletePosixAccountRequest)
    ),
)
_sym_db.RegisterMessage(DeletePosixAccountRequest)

DeleteSshPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteSshPublicKeyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETESSHPUBLICKEYREQUEST,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A request message for deleting an SSH public key.
  
  
  Attributes:
      name:
          The fingerprint of the public key to update. Public keys are
          identified by their SHA-256 fingerprint. The fingerprint of
          the public key is in format
          ``users/{user}/sshPublicKeys/{fingerprint}``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.DeleteSshPublicKeyRequest)
    ),
)
_sym_db.RegisterMessage(DeleteSshPublicKeyRequest)

GetLoginProfileRequest = _reflection.GeneratedProtocolMessageType(
    "GetLoginProfileRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETLOGINPROFILEREQUEST,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A request message for retrieving the login profile information for a
  user.
  
  
  Attributes:
      name:
          The unique ID for the user in format ``users/{user}``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.GetLoginProfileRequest)
    ),
)
_sym_db.RegisterMessage(GetLoginProfileRequest)

GetSshPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    "GetSshPublicKeyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETSSHPUBLICKEYREQUEST,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A request message for retrieving an SSH public key.
  
  
  Attributes:
      name:
          The fingerprint of the public key to retrieve. Public keys are
          identified by their SHA-256 fingerprint. The fingerprint of
          the public key is in format
          ``users/{user}/sshPublicKeys/{fingerprint}``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.GetSshPublicKeyRequest)
    ),
)
_sym_db.RegisterMessage(GetSshPublicKeyRequest)

ImportSshPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    "ImportSshPublicKeyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMPORTSSHPUBLICKEYREQUEST,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A request message for importing an SSH public key.
  
  
  Attributes:
      parent:
          The unique ID for the user in format ``users/{user}``.
      ssh_public_key:
          The SSH public key and expiration time.
      project_id:
          The project ID of the Google Cloud Platform project.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.ImportSshPublicKeyRequest)
    ),
)
_sym_db.RegisterMessage(ImportSshPublicKeyRequest)

ImportSshPublicKeyResponse = _reflection.GeneratedProtocolMessageType(
    "ImportSshPublicKeyResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMPORTSSHPUBLICKEYRESPONSE,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A response message for importing an SSH public key.
  
  
  Attributes:
      login_profile:
          The login profile information for the user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.ImportSshPublicKeyResponse)
    ),
)
_sym_db.RegisterMessage(ImportSshPublicKeyResponse)

UpdateSshPublicKeyRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateSshPublicKeyRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATESSHPUBLICKEYREQUEST,
        __module__="google.cloud.oslogin_v1.proto.oslogin_pb2",
        __doc__="""A request message for updating an SSH public key.
  
  
  Attributes:
      name:
          The fingerprint of the public key to update. Public keys are
          identified by their SHA-256 fingerprint. The fingerprint of
          the public key is in format
          ``users/{user}/sshPublicKeys/{fingerprint}``.
      ssh_public_key:
          The SSH public key and expiration time.
      update_mask:
          Mask to control which fields get updated. Updates all if not
          present.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.v1.UpdateSshPublicKeyRequest)
    ),
)
_sym_db.RegisterMessage(UpdateSshPublicKeyRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(
    descriptor_pb2.FileOptions(),
    _b(
        "\n\033com.google.cloud.oslogin.v1B\014OsLoginProtoP\001Z>google.golang.org/genproto/googleapis/cloud/oslogin/v1;oslogin\252\002\027Google.Cloud.OsLogin.V1\312\002\027Google\\Cloud\\OsLogin\\V1"
    ),
)
_LOGINPROFILE_SSHPUBLICKEYSENTRY.has_options = True
_LOGINPROFILE_SSHPUBLICKEYSENTRY._options = _descriptor._ParseOptions(
    descriptor_pb2.MessageOptions(), _b("8\001")
)

_OSLOGINSERVICE = _descriptor.ServiceDescriptor(
    name="OsLoginService",
    full_name="google.cloud.oslogin.v1.OsLoginService",
    file=DESCRIPTOR,
    index=0,
    options=None,
    serialized_start=1056,
    serialized_end=2029,
    methods=[
        _descriptor.MethodDescriptor(
            name="DeletePosixAccount",
            full_name="google.cloud.oslogin.v1.OsLoginService.DeletePosixAccount",
            index=0,
            containing_service=None,
            input_type=_DELETEPOSIXACCOUNTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            options=_descriptor._ParseOptions(
                descriptor_pb2.MethodOptions(),
                _b("\202\323\344\223\002\037*\035/v1/{name=users/*/projects/*}"),
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteSshPublicKey",
            full_name="google.cloud.oslogin.v1.OsLoginService.DeleteSshPublicKey",
            index=1,
            containing_service=None,
            input_type=_DELETESSHPUBLICKEYREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            options=_descriptor._ParseOptions(
                descriptor_pb2.MethodOptions(),
                _b('\202\323\344\223\002$*"/v1/{name=users/*/sshPublicKeys/*}'),
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetLoginProfile",
            full_name="google.cloud.oslogin.v1.OsLoginService.GetLoginProfile",
            index=2,
            containing_service=None,
            input_type=_GETLOGINPROFILEREQUEST,
            output_type=_LOGINPROFILE,
            options=_descriptor._ParseOptions(
                descriptor_pb2.MethodOptions(),
                _b("\202\323\344\223\002!\022\037/v1/{name=users/*}/loginProfile"),
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetSshPublicKey",
            full_name="google.cloud.oslogin.v1.OsLoginService.GetSshPublicKey",
            index=3,
            containing_service=None,
            input_type=_GETSSHPUBLICKEYREQUEST,
            output_type=google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2._SSHPUBLICKEY,
            options=_descriptor._ParseOptions(
                descriptor_pb2.MethodOptions(),
                _b('\202\323\344\223\002$\022"/v1/{name=users/*/sshPublicKeys/*}'),
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ImportSshPublicKey",
            full_name="google.cloud.oslogin.v1.OsLoginService.ImportSshPublicKey",
            index=4,
            containing_service=None,
            input_type=_IMPORTSSHPUBLICKEYREQUEST,
            output_type=_IMPORTSSHPUBLICKEYRESPONSE,
            options=_descriptor._ParseOptions(
                descriptor_pb2.MethodOptions(),
                _b(
                    "\202\323\344\223\0029\"'/v1/{parent=users/*}:importSshPublicKey:\016ssh_public_key"
                ),
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateSshPublicKey",
            full_name="google.cloud.oslogin.v1.OsLoginService.UpdateSshPublicKey",
            index=5,
            containing_service=None,
            input_type=_UPDATESSHPUBLICKEYREQUEST,
            output_type=google_dot_cloud_dot_oslogin_dot_common_dot_common__pb2._SSHPUBLICKEY,
            options=_descriptor._ParseOptions(
                descriptor_pb2.MethodOptions(),
                _b(
                    '\202\323\344\223\00242"/v1/{name=users/*/sshPublicKeys/*}:\016ssh_public_key'
                ),
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_OSLOGINSERVICE)

DESCRIPTOR.services_by_name["OsLoginService"] = _OSLOGINSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/oslogin/common/common.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/oslogin/common/common.proto",
    package="google.cloud.oslogin.common",
    syntax="proto3",
    serialized_pb=_b(
        '\n(google/cloud/oslogin/common/common.proto\x12\x1bgoogle.cloud.oslogin.common\x1a\x1cgoogle/api/annotations.proto"\xa8\x01\n\x0cPosixAccount\x12\x0f\n\x07primary\x18\x01 \x01(\x08\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\x03\x12\x0b\n\x03gid\x18\x04 \x01(\x03\x12\x16\n\x0ehome_directory\x18\x05 \x01(\t\x12\r\n\x05shell\x18\x06 \x01(\t\x12\r\n\x05gecos\x18\x07 \x01(\t\x12\x11\n\tsystem_id\x18\x08 \x01(\t\x12\x12\n\naccount_id\x18\t \x01(\t"N\n\x0cSshPublicKey\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpiration_time_usec\x18\x02 \x01(\x03\x12\x13\n\x0b\x66ingerprint\x18\x03 \x01(\tB\xae\x01\n\x1f\x63om.google.cloud.oslogin.commonB\x0cOsLoginProtoZAgoogle.golang.org/genproto/googleapis/cloud/oslogin/common;common\xaa\x02\x1bGoogle.Cloud.OsLogin.Common\xca\x02\x1bGoogle\\Cloud\\OsLogin\\Commonb\x06proto3'
    ),
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_POSIXACCOUNT = _descriptor.Descriptor(
    name="PosixAccount",
    full_name="google.cloud.oslogin.common.PosixAccount",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="primary",
            full_name="google.cloud.oslogin.common.PosixAccount.primary",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="username",
            full_name="google.cloud.oslogin.common.PosixAccount.username",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="uid",
            full_name="google.cloud.oslogin.common.PosixAccount.uid",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="gid",
            full_name="google.cloud.oslogin.common.PosixAccount.gid",
            index=3,
            number=4,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="home_directory",
            full_name="google.cloud.oslogin.common.PosixAccount.home_directory",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="shell",
            full_name="google.cloud.oslogin.common.PosixAccount.shell",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="gecos",
            full_name="google.cloud.oslogin.common.PosixAccount.gecos",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="system_id",
            full_name="google.cloud.oslogin.common.PosixAccount.system_id",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="account_id",
            full_name="google.cloud.oslogin.common.PosixAccount.account_id",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=104,
    serialized_end=272,
)


_SSHPUBLICKEY = _descriptor.Descriptor(
    name="SshPublicKey",
    full_name="google.cloud.oslogin.common.SshPublicKey",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.oslogin.common.SshPublicKey.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="expiration_time_usec",
            full_name="google.cloud.oslogin.common.SshPublicKey.expiration_time_usec",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
        _descriptor.FieldDescriptor(
            name="fingerprint",
            full_name="google.cloud.oslogin.common.SshPublicKey.fingerprint",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            options=None,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=274,
    serialized_end=352,
)

DESCRIPTOR.message_types_by_name["PosixAccount"] = _POSIXACCOUNT
DESCRIPTOR.message_types_by_name["SshPublicKey"] = _SSHPUBLICKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PosixAccount = _reflection.GeneratedProtocolMessageType(
    "PosixAccount",
    (_message.Message,),
    dict(
        DESCRIPTOR=_POSIXACCOUNT,
        __module__="google.cloud.oslogin.common.common_pb2",
        __doc__="""The POSIX account information associated with a Google account.
  
  
  Attributes:
      primary:
          Only one POSIX account can be marked as primary.
      username:
          The username of the POSIX account.
      uid:
          The user ID.
      gid:
          The default group ID.
      home_directory:
          The path to the home directory for this account.
      shell:
          The path to the logic shell for this account.
      gecos:
          The GECOS (user information) entry for this account.
      system_id:
          System identifier for which account the username or uid
          applies to. By default, the empty value is used.
      account_id:
          Output only. A POSIX account identifier.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.common.PosixAccount)
    ),
)
_sym_db.RegisterMessage(PosixAccount)

SshPublicKey = _reflection.GeneratedProtocolMessageType(
    "SshPublicKey",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SSHPUBLICKEY,
        __module__="google.cloud.oslogin.common.common_pb2",
        __doc__="""The SSH public key information associated with a Google account.
  
  
  Attributes:
      key:
          Public key text in SSH format, defined by RFC4253 section 6.6.
      expiration_time_usec:
          An expiration time in microseconds since epoch.
      fingerprint:
          Output only. The SHA-256 fingerprint of the SSH public key.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.oslogin.common.SshPublicKey)
    ),
)
_sym_db.RegisterMessage(SshPublicKey)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(
    descriptor_pb2.FileOptions(),
    _b(
        "\n\037com.google.cloud.oslogin.commonB\014OsLoginProtoZAgoogle.golang.org/genproto/googleapis/cloud/oslogin/common;common\252\002\033Google.Cloud.OsLogin.Common\312\002\033Google\\Cloud\\OsLogin\\Common"
    ),
)
# @@protoc_insertion_point(module_scope)
